@@ -1,27 +1,27 @@
 /* -*- mode: c; c-basic-offset: 2 -*- */
-/* 
+/*
  * Copyright (C) 2007-2012 David Bird (Coova Technologies) <support@coova.com>
- * 
+ *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- * 
+ *
  */
 /*
  * $Id: patricia.c,v 1.7 2005/12/07 20:46:41 dplonka Exp $
  * Dave Plonka <plonka@doit.wisc.edu>
  *
  * This product includes software developed by the University of Michigan,
- * Merit Network, Inc., and their contributors. 
+ * Merit Network, Inc., and their contributors.
  *
  * This file had been called "radix.c" in the MRT sources.
  *
@@ -40,18 +40,18 @@ prefix_tochar (prefix_t * prefix)
 {
   if (prefix == NULL)
     return (NULL);
-  
+
   return ((u_char *) & prefix->add.sin);
 }
 
-int 
+int
 comp_with_mask (void *addr, void *dest, u_int mask)
 {
-  
+
   if ( /* mask/8 == 0 || */ memcmp (addr, dest, mask / 8) == 0) {
     int n = mask / 8;
     int m = ((-1) << (8 - (mask % 8)));
-    
+
     if (mask % 8 == 0 || (((u_char *)addr)[n] & m) == (((u_char *)dest)[n] & m))
       return (1);
   }
@@ -65,7 +65,7 @@ my_inet_pton (int af, const char *src, void *dst)
   if (af == AF_INET) {
     int i, c, val;
     u_char xp[sizeof(struct in_addr)] = {0, 0, 0, 0};
-    
+
     for (i = 0; ; i++) {
       c = *src++;
       if (!isdigit (c))
@@ -101,7 +101,7 @@ my_inet_pton (int af, const char *src, void *dst)
 
 #define PATRICIA_MAX_THREADS		16
 
-/* 
+/*
  * convert prefix information to ascii string with length
  * thread safe and (almost) re-entrant implementation
  */
@@ -112,12 +112,12 @@ prefix_toa2x (prefix_t *prefix, char *buff, int with_len)
     return ("(Null)");
   assert (prefix->ref_count >= 0);
   if (buff == NULL) {
-    
+
     struct buffer {
       char buffs[PATRICIA_MAX_THREADS][48+5];
       u_int i;
     } *buffp;
-    
+
 #    if 0
     THREAD_SPECIFIC_DATA (struct buffer, buffp, 1);
 #    else
@@ -130,7 +130,7 @@ prefix_toa2x (prefix_t *prefix, char *buff, int with_len)
       /* XXX should we report an error? */
       return (NULL);
     }
-    
+
     buff = buffp->buffs[buffp->i++%PATRICIA_MAX_THREADS];
   }
   if (prefix->family == AF_INET) {
@@ -183,7 +183,7 @@ patricia_prefix_new2 (int family, void *dest, int bitlen, prefix_t *prefix)
 {
   int dynamic_allocated = 0;
   int default_bitlen = sizeof(struct in_addr) * 8;
-  
+
 #ifdef HAVE_IPV6
   if (family == AF_INET6) {
     default_bitlen = sizeof(struct in6_addr) * 8;
@@ -202,9 +202,9 @@ patricia_prefix_new2 (int family, void *dest, int bitlen, prefix_t *prefix)
 #else
 	//for some reason, compiler is getting
 	//prefix4_t size incorrect on NT
-	prefix = calloc(1, sizeof (prefix_t)); 
+	prefix = calloc(1, sizeof (prefix_t));
 #endif /* NT */
-	
+
 	dynamic_allocated++;
       }
       memcpy (&prefix->add.sin, dest, sizeof(struct in_addr));
@@ -212,7 +212,7 @@ patricia_prefix_new2 (int family, void *dest, int bitlen, prefix_t *prefix)
     else {
       return (NULL);
     }
-  
+
   prefix->bitlen = (bitlen >= 0)? bitlen: default_bitlen;
   prefix->family = family;
   prefix->ref_count = 0;
@@ -242,10 +242,10 @@ ascii2prefix (int family, char *string)
 #endif /* HAVE_IPV6 */
   int result;
   char save[MAXLINE];
-  
+
   if (string == NULL)
     return (NULL);
-  
+
   /* easy way to handle both families */
   if (family == 0) {
     family = AF_INET;
@@ -253,7 +253,7 @@ ascii2prefix (int family, char *string)
     if (strchr (string, ':')) family = AF_INET6;
 #endif /* HAVE_IPV6 */
   }
-  
+
   if (family == AF_INET) {
     maxbitlen = sizeof(struct in_addr) * 8;
   }
@@ -262,7 +262,7 @@ ascii2prefix (int family, char *string)
     maxbitlen = sizeof(struct in6_addr) * 8;
   }
 #endif /* HAVE_IPV6 */
-  
+
   if ((cp = strchr (string, '/')) != NULL) {
     bitlen = atol (cp + 1);
     /* *cp = '\0'; */
@@ -277,13 +277,13 @@ ascii2prefix (int family, char *string)
   else {
     bitlen = maxbitlen;
   }
-  
+
   if (family == AF_INET) {
     if ((result = my_inet_pton (AF_INET, string, &sin)) <= 0)
       return (NULL);
     return (patricia_prefix_new (AF_INET, &sin, bitlen));
   }
-  
+
 #ifdef HAVE_IPV6
   else if (family == AF_INET6) {
     // Get rid of this with next IPv6 upgrade
@@ -315,14 +315,14 @@ patricia_prefix_ref (prefix_t * prefix)
   return (prefix);
 }
 
-void 
+void
 patricia_prefix_deref (prefix_t * prefix)
 {
   if (prefix == NULL)
     return;
   /* for secure programming, raise an assert. no static prefix can call this */
   assert (prefix->ref_count > 0);
-  
+
   prefix->ref_count--;
   assert (prefix->ref_count >= 0);
   if (prefix->ref_count <= 0) {
@@ -339,7 +339,7 @@ patricia_tree_t *
 patricia_new (int maxbits)
 {
   patricia_tree_t *patricia = calloc(1, sizeof *patricia);
-  
+
   patricia->maxbits = maxbits;
   patricia->head = NULL;
   patricia->num_active_node = 0;
@@ -358,15 +358,15 @@ patricia_clear (patricia_tree_t *patricia, void_fn_t func)
 {
   assert (patricia);
   if (patricia->head) {
-    
+
     patricia_node_t *Xstack[PATRICIA_MAXBITS+1];
     patricia_node_t **Xsp = Xstack;
     patricia_node_t *Xrn = patricia->head;
-    
+
     while (Xrn) {
       patricia_node_t *l = Xrn->l;
       patricia_node_t *r = Xrn->r;
-      
+
       if (Xrn->prefix) {
 	patricia_prefix_deref (Xrn->prefix);
 	if (Xrn->data && func)
@@ -377,7 +377,7 @@ patricia_clear (patricia_tree_t *patricia, void_fn_t func)
       }
       free (Xrn);
       patricia->num_active_node--;
-      
+
       if (l) {
 	if (r) {
 	  *Xsp++ = r;
@@ -412,7 +412,7 @@ patricia_process (patricia_tree_t *patricia, void_fn_t func)
 {
   patricia_node_t *node;
   assert (func);
-  
+
   PATRICIA_WALK (patricia->head, node) {
     func (node->prefix, node->data);
   } PATRICIA_WALK_END;
@@ -423,20 +423,20 @@ patricia_walk_inorder(patricia_node_t *node, void_fn_t func)
 {
   size_t n = 0;
   assert(func);
-  
+
   if (node->l) {
     n += patricia_walk_inorder(node->l, func);
   }
-  
+
   if (node->prefix) {
     func(node->prefix, node->data);
     n++;
   }
-  
+
   if (node->r) {
     n += patricia_walk_inorder(node->r, func);
   }
-  
+
   return n;
 }
 
@@ -447,55 +447,55 @@ patricia_search_exact (patricia_tree_t *patricia, prefix_t *prefix)
   patricia_node_t *node;
   u_char *addr;
   u_int bitlen;
-  
+
   assert (patricia);
   assert (prefix);
   assert (prefix->bitlen <= patricia->maxbits);
-  
+
   if (patricia->head == NULL)
     return (NULL);
-  
+
   node = patricia->head;
   addr = prefix_touchar (prefix);
   bitlen = prefix->bitlen;
-  
+
   while (node->bit < bitlen) {
-    
+
     if (BIT_TEST (addr[node->bit >> 3], 0x80 >> (node->bit & 0x07))) {
 #ifdef PATRICIA_DEBUG
       if (node->prefix) {
-	log_dbg( "patricia_search_exact: take right %s/%d", 
-		 prefix_toa (node->prefix), node->prefix->bitlen);
+	syslog(LOG_DEBUG,  "patricia_search_exact: take right %s/%d",
+               prefix_toa (node->prefix), node->prefix->bitlen);
       } else {
-	log_dbg( "patricia_search_exact: take right at %u", 
-		 node->bit);
+	syslog(LOG_DEBUG,  "patricia_search_exact: take right at %u",
+               node->bit);
       }
 #endif /* PATRICIA_DEBUG */
       node = node->r;
-	}
+    }
     else {
 #ifdef PATRICIA_DEBUG
       if (node->prefix) {
-	log_dbg( "patricia_search_exact: take left %s/%d", 
-		 prefix_toa (node->prefix), node->prefix->bitlen);
-      } else { 
-	log_dbg( "patricia_search_exact: take left at %u", 
-		 node->bit);
+	syslog(LOG_DEBUG,  "patricia_search_exact: take left %s/%d",
+               prefix_toa (node->prefix), node->prefix->bitlen);
+      } else {
+	syslog(LOG_DEBUG,  "patricia_search_exact: take left at %u",
+               node->bit);
       }
 #endif /* PATRICIA_DEBUG */
       node = node->l;
     }
-    
+
     if (node == NULL)
       return (NULL);
   }
-  
+
 #ifdef PATRICIA_DEBUG
   if (node->prefix) {
-    log_dbg( "patricia_search_exact: stop at %s/%d", 
-	     prefix_toa (node->prefix), node->prefix->bitlen);
+    syslog(LOG_DEBUG,  "patricia_search_exact: stop at %s/%d",
+           prefix_toa (node->prefix), node->prefix->bitlen);
   } else {
-    log_dbg( "patricia_search_exact: stop at %u", node->bit);
+    syslog(LOG_DEBUG,  "patricia_search_exact: stop at %u", node->bit);
   }
 #endif /* PATRICIA_DEBUG */
   if (node->bit > bitlen || node->prefix == NULL)
@@ -505,8 +505,8 @@ patricia_search_exact (patricia_tree_t *patricia, prefix_t *prefix)
   if (comp_with_mask (prefix_tochar (node->prefix), prefix_tochar (prefix),
 		      bitlen)) {
 #ifdef PATRICIA_DEBUG
-    log_dbg( "patricia_search_exact: found %s/%d", 
-	     prefix_toa (node->prefix), node->prefix->bitlen);
+    syslog(LOG_DEBUG,  "patricia_search_exact: found %s/%d",
+           prefix_toa (node->prefix), node->prefix->bitlen);
 #endif /* PATRICIA_DEBUG */
     return (node);
   }
@@ -523,36 +523,36 @@ patricia_search_best2 (patricia_tree_t *patricia, prefix_t *prefix, int inclusiv
   u_char *addr;
   u_int bitlen;
   int cnt = 0;
-  
+
   assert (patricia);
   assert (prefix);
   assert (prefix->bitlen <= patricia->maxbits);
-  
+
   if (patricia->head == NULL)
     return (NULL);
-  
+
   node = patricia->head;
   addr = prefix_touchar (prefix);
   bitlen = prefix->bitlen;
-  
+
   while (node->bit < bitlen) {
-    
+
     if (node->prefix) {
 #ifdef PATRICIA_DEBUG
-      log_dbg( "patricia_search_best: push %s/%d", 
-	       prefix_toa (node->prefix), node->prefix->bitlen);
+      syslog(LOG_DEBUG,  "patricia_search_best: push %s/%d",
+             prefix_toa (node->prefix), node->prefix->bitlen);
 #endif /* PATRICIA_DEBUG */
       stack[cnt++] = node;
     }
-    
+
     if (BIT_TEST (addr[node->bit >> 3], 0x80 >> (node->bit & 0x07))) {
 #ifdef PATRICIA_DEBUG
       if (node->prefix) {
-	log_dbg( "patricia_search_best: take right %s/%d", 
-		 prefix_toa (node->prefix), node->prefix->bitlen);
+	syslog(LOG_DEBUG,  "patricia_search_best: take right %s/%d",
+               prefix_toa (node->prefix), node->prefix->bitlen);
       } else {
-	log_dbg( "patricia_search_best: take right at %u", 
-		 node->bit);
+	syslog(LOG_DEBUG,  "patricia_search_best: take right at %u",
+               node->bit);
       }
 #endif /* PATRICIA_DEBUG */
       node = node->r;
@@ -560,49 +560,49 @@ patricia_search_best2 (patricia_tree_t *patricia, prefix_t *prefix, int inclusiv
     else {
 #ifdef PATRICIA_DEBUG
       if (node->prefix) {
-	log_dbg( "patricia_search_best: take left %s/%d", 
-		 prefix_toa (node->prefix), node->prefix->bitlen);
+	syslog(LOG_DEBUG,  "patricia_search_best: take left %s/%d",
+               prefix_toa (node->prefix), node->prefix->bitlen);
       } else {
-	log_dbg( "patricia_search_best: take left at %u", 
-		 node->bit);
+	syslog(LOG_DEBUG,  "patricia_search_best: take left at %u",
+               node->bit);
       }
 #endif /* PATRICIA_DEBUG */
       node = node->l;
     }
-    
+
     if (node == NULL)
       break;
   }
-  
+
   if (inclusive && node && node->prefix)
     stack[cnt++] = node;
-  
+
 #ifdef PATRICIA_DEBUG
   if (node == NULL) {
-    log_dbg( "patricia_search_best: stop at null");
+    syslog(LOG_DEBUG,  "patricia_search_best: stop at null");
   } else if (node->prefix) {
-    log_dbg( "patricia_search_best: stop at %s/%d", 
-	     prefix_toa (node->prefix), node->prefix->bitlen);
+    syslog(LOG_DEBUG,  "patricia_search_best: stop at %s/%d",
+           prefix_toa (node->prefix), node->prefix->bitlen);
   } else {
-    log_dbg( "patricia_search_best: stop at %u", node->bit);
+    syslog(LOG_DEBUG,  "patricia_search_best: stop at %u", node->bit);
   }
 #endif /* PATRICIA_DEBUG */
-  
+
   if (cnt <= 0)
     return (NULL);
-  
+
   while (--cnt >= 0) {
     node = stack[cnt];
 #ifdef PATRICIA_DEBUG
-    log_dbg( "patricia_search_best: pop %s/%d", 
-	     prefix_toa (node->prefix), node->prefix->bitlen);
+    syslog(LOG_DEBUG,  "patricia_search_best: pop %s/%d",
+           prefix_toa (node->prefix), node->prefix->bitlen);
 #endif /* PATRICIA_DEBUG */
-    if (comp_with_mask (prefix_tochar (node->prefix), 
+    if (comp_with_mask (prefix_tochar (node->prefix),
 			prefix_tochar (prefix),
 			node->prefix->bitlen) && node->prefix->bitlen <= bitlen) {
 
-      log_dbg( "patricia_search_best: found %s/%d", 
-	       prefix_toa (node->prefix), node->prefix->bitlen);
+      syslog(LOG_DEBUG,  "patricia_search_best: found %s/%d",
+             prefix_toa (node->prefix), node->prefix->bitlen);
 
       return (node);
     }
@@ -625,11 +625,11 @@ patricia_lookup (patricia_tree_t *patricia, prefix_t *prefix)
   u_char *addr, *test_addr;
   u_int bitlen, check_bit, differ_bit;
   int i, j, r;
-  
+
   assert (patricia);
   assert (prefix);
   assert (prefix->bitlen <= patricia->maxbits);
-  
+
   if (patricia->head == NULL) {
     node = calloc(1, sizeof *node);
     node->bit = prefix->bitlen;
@@ -639,29 +639,29 @@ patricia_lookup (patricia_tree_t *patricia, prefix_t *prefix)
     node->data = NULL;
     patricia->head = node;
 #ifdef PATRICIA_DEBUG
-    log_dbg( "patricia_lookup: new_node #0 %s/%d (head)", 
-	     prefix_toa (prefix), prefix->bitlen);
+    syslog(LOG_DEBUG,  "patricia_lookup: new_node #0 %s/%d (head)",
+           prefix_toa (prefix), prefix->bitlen);
 #endif /* PATRICIA_DEBUG */
     patricia->num_active_node++;
     return (node);
   }
-  
+
   addr = prefix_touchar (prefix);
   bitlen = prefix->bitlen;
   node = patricia->head;
-  
+
   while (node->bit < bitlen || node->prefix == NULL) {
-    
+
     if (node->bit < patricia->maxbits &&
 	BIT_TEST (addr[node->bit >> 3], 0x80 >> (node->bit & 0x07))) {
       if (node->r == NULL)
 	break;
 #ifdef PATRICIA_DEBUG
       if (node->prefix) {
-	log_dbg( "patricia_lookup: take right %s/%d", 
-		 prefix_toa (node->prefix), node->prefix->bitlen);
+	syslog(LOG_DEBUG,  "patricia_lookup: take right %s/%d",
+               prefix_toa (node->prefix), node->prefix->bitlen);
       } else {
-	log_dbg( "patricia_lookup: take right at %u", node->bit);
+	syslog(LOG_DEBUG,  "patricia_lookup: take right at %u", node->bit);
       }
 #endif /* PATRICIA_DEBUG */
       node = node->r;
@@ -671,24 +671,24 @@ patricia_lookup (patricia_tree_t *patricia, prefix_t *prefix)
 	break;
 #ifdef PATRICIA_DEBUG
       if (node->prefix) {
-	log_dbg( "patricia_lookup: take left %s/%d", 
-		 prefix_toa (node->prefix), node->prefix->bitlen);
+	syslog(LOG_DEBUG,  "patricia_lookup: take left %s/%d",
+               prefix_toa (node->prefix), node->prefix->bitlen);
       } else {
-	log_dbg( "patricia_lookup: take left at %u", node->bit);
+	syslog(LOG_DEBUG,  "patricia_lookup: take left at %u", node->bit);
       }
 #endif /* PATRICIA_DEBUG */
       node = node->l;
     }
-    
+
     assert (node);
   }
-  
+
   assert (node->prefix);
 #ifdef PATRICIA_DEBUG
-  log_dbg( "patricia_lookup: stop at %s/%d", 
-	   prefix_toa (node->prefix), node->prefix->bitlen);
+  syslog(LOG_DEBUG,  "patricia_lookup: stop at %s/%d",
+         prefix_toa (node->prefix), node->prefix->bitlen);
 #endif /* PATRICIA_DEBUG */
-  
+
   test_addr = prefix_touchar (node->prefix);
   /* find the first bit different */
   check_bit = (node->bit < bitlen)? node->bit: bitlen;
@@ -711,40 +711,40 @@ patricia_lookup (patricia_tree_t *patricia, prefix_t *prefix)
   if (differ_bit > check_bit)
     differ_bit = check_bit;
 #ifdef PATRICIA_DEBUG
-  log_dbg( "patricia_lookup: differ_bit %d", differ_bit);
+  syslog(LOG_DEBUG,  "patricia_lookup: differ_bit %d", differ_bit);
 #endif /* PATRICIA_DEBUG */
-  
+
   parent = node->parent;
   while (parent && parent->bit >= differ_bit) {
     node = parent;
     parent = node->parent;
 #ifdef PATRICIA_DEBUG
     if (node->prefix) {
-      log_dbg( "patricia_lookup: up to %s/%d", 
-	       prefix_toa (node->prefix), node->prefix->bitlen);
+      syslog(LOG_DEBUG,  "patricia_lookup: up to %s/%d",
+             prefix_toa (node->prefix), node->prefix->bitlen);
     } else {
-      log_dbg( "patricia_lookup: up to %u", node->bit);
+      syslog(LOG_DEBUG,  "patricia_lookup: up to %u", node->bit);
     }
 #endif /* PATRICIA_DEBUG */
   }
-  
+
   if (differ_bit == bitlen && node->bit == bitlen) {
     if (node->prefix) {
-#ifdef PATRICIA_DEBUG 
-      log_dbg( "patricia_lookup: found %s/%d", 
-	       prefix_toa (node->prefix), node->prefix->bitlen);
+#ifdef PATRICIA_DEBUG
+      syslog(LOG_DEBUG,  "patricia_lookup: found %s/%d",
+             prefix_toa (node->prefix), node->prefix->bitlen);
 #endif /* PATRICIA_DEBUG */
       return (node);
-	}
+    }
     node->prefix = patricia_prefix_ref (prefix);
 #ifdef PATRICIA_DEBUG
-    log_dbg( "patricia_lookup: new node #1 %s/%d (glue mod)",
-	     prefix_toa (prefix), prefix->bitlen);
+    syslog(LOG_DEBUG,  "patricia_lookup: new node #1 %s/%d (glue mod)",
+           prefix_toa (prefix), prefix->bitlen);
 #endif /* PATRICIA_DEBUG */
     assert (node->data == NULL);
-	return (node);
+    return (node);
   }
-  
+
   new_node = calloc(1, sizeof *new_node);
   new_node->bit = prefix->bitlen;
   new_node->prefix = patricia_prefix_ref (prefix);
@@ -765,12 +765,12 @@ patricia_lookup (patricia_tree_t *patricia, prefix_t *prefix)
       node->l = new_node;
     }
 #ifdef PATRICIA_DEBUG
-    log_dbg( "patricia_lookup: new_node #2 %s/%d (child)", 
-	     prefix_toa (prefix), prefix->bitlen);
+    syslog(LOG_DEBUG,  "patricia_lookup: new_node #2 %s/%d (child)",
+           prefix_toa (prefix), prefix->bitlen);
 #endif /* PATRICIA_DEBUG */
     return (new_node);
   }
-  
+
   if (bitlen == differ_bit) {
     if (bitlen < patricia->maxbits &&
 	BIT_TEST (test_addr[bitlen >> 3], 0x80 >> (bitlen & 0x07))) {
@@ -792,8 +792,8 @@ patricia_lookup (patricia_tree_t *patricia, prefix_t *prefix)
     }
     node->parent = new_node;
 #ifdef PATRICIA_DEBUG
-    log_dbg( "patricia_lookup: new_node #3 %s/%d (parent)", 
-	     prefix_toa (prefix), prefix->bitlen);
+    syslog(LOG_DEBUG,  "patricia_lookup: new_node #3 %s/%d (parent)",
+           prefix_toa (prefix), prefix->bitlen);
 #endif /* PATRICIA_DEBUG */
   }
   else {
@@ -813,7 +813,7 @@ patricia_lookup (patricia_tree_t *patricia, prefix_t *prefix)
       glue->l = new_node;
     }
     new_node->parent = glue;
-    
+
     if (node->parent == NULL) {
       assert (patricia->head == node);
       patricia->head = glue;
@@ -826,8 +826,8 @@ patricia_lookup (patricia_tree_t *patricia, prefix_t *prefix)
     }
     node->parent = glue;
 #ifdef PATRICIA_DEBUG
-    log_dbg( "patricia_lookup: new_node #4 %s/%d (glue+node)", 
-	     prefix_toa (prefix), prefix->bitlen);
+    syslog(LOG_DEBUG,  "patricia_lookup: new_node #4 %s/%d (glue+node)",
+           prefix_toa (prefix), prefix->bitlen);
 #endif /* PATRICIA_DEBUG */
   }
   return (new_node);
@@ -838,42 +838,42 @@ void
 patricia_remove (patricia_tree_t *patricia, patricia_node_t *node)
 {
   patricia_node_t *parent, *child;
-  
+
   assert (patricia);
   assert (node);
-  
+
   if (node->r && node->l) {
 #ifdef PATRICIA_DEBUG
-    log_dbg( "patricia_remove: #0 %s/%d (r & l)", 
-	     prefix_toa (node->prefix), node->prefix->bitlen);
+    syslog(LOG_DEBUG,  "patricia_remove: #0 %s/%d (r & l)",
+           prefix_toa (node->prefix), node->prefix->bitlen);
 #endif /* PATRICIA_DEBUG */
-    
+
     /* this might be a placeholder node -- have to check and make sure
      * there is a prefix aossciated with it ! */
-    if (node->prefix != NULL) 
+    if (node->prefix != NULL)
       patricia_prefix_deref (node->prefix);
     node->prefix = NULL;
     /* Also I needed to clear data pointer -- masaki */
     node->data = NULL;
     return;
   }
-  
+
   if (node->r == NULL && node->l == NULL) {
 #ifdef PATRICIA_DEBUG
-    log_dbg( "patricia_remove: #1 %s/%d (!r & !l)", 
-	     prefix_toa (node->prefix), node->prefix->bitlen);
+    syslog(LOG_DEBUG,  "patricia_remove: #1 %s/%d (!r & !l)",
+           prefix_toa (node->prefix), node->prefix->bitlen);
 #endif /* PATRICIA_DEBUG */
     parent = node->parent;
     patricia_prefix_deref (node->prefix);
     free (node);
     patricia->num_active_node--;
-    
+
     if (parent == NULL) {
       assert (patricia->head == node);
       patricia->head = NULL;
       return;
     }
-    
+
     if (parent->r == node) {
       parent->r = NULL;
       child = parent->l;
@@ -883,12 +883,12 @@ patricia_remove (patricia_tree_t *patricia, patricia_node_t *node)
       parent->l = NULL;
       child = parent->r;
     }
-    
+
     if (parent->prefix)
       return;
-    
+
     /* we need to remove parent too */
-    
+
     if (parent->parent == NULL) {
       assert (patricia->head == parent);
       patricia->head = child;
@@ -905,10 +905,10 @@ patricia_remove (patricia_tree_t *patricia, patricia_node_t *node)
     patricia->num_active_node--;
     return;
   }
-  
+
 #ifdef PATRICIA_DEBUG
-  log_dbg( "patricia_remove: #2 %s/%d (r ^ l)", 
-	   prefix_toa (node->prefix), node->prefix->bitlen);
+  syslog(LOG_DEBUG,  "patricia_remove: #2 %s/%d (r ^ l)",
+         prefix_toa (node->prefix), node->prefix->bitlen);
 #endif /* PATRICIA_DEBUG */
   if (node->r) {
     child = node->r;
@@ -919,17 +919,17 @@ patricia_remove (patricia_tree_t *patricia, patricia_node_t *node)
   }
   parent = node->parent;
   child->parent = parent;
-  
+
   patricia_prefix_deref (node->prefix);
   free (node);
   patricia->num_active_node--;
-  
+
   if (parent == NULL) {
     assert (patricia->head == node);
     patricia->head = child;
     return;
   }
-  
+
   if (parent->r == node) {
     parent->r = child;
   }
@@ -944,7 +944,7 @@ make_and_lookup (patricia_tree_t *tree, char *string)
 {
   prefix_t *prefix;
   patricia_node_t *node;
-  
+
   prefix = ascii2prefix (AF_INET, string);
   printf ("make_and_lookup: %s/%d", prefix_toa (prefix), prefix->bitlen);
   node = patricia_lookup (tree, prefix);
@@ -957,14 +957,14 @@ try_search_exact (patricia_tree_t *tree, char *string)
 {
   prefix_t *prefix;
   patricia_node_t *node;
-  
+
   prefix = ascii2prefix (AF_INET, string);
   printf ("try_search_exact: %s/%d", prefix_toa (prefix), prefix->bitlen);
   if ((node = patricia_search_exact (tree, prefix)) == NULL) {
     printf ("try_search_exact: not found");
   }
   else {
-    printf ("try_search_exact: %s/%d found", 
+    printf ("try_search_exact: %s/%d found",
 	    prefix_toa (node->prefix), node->prefix->bitlen);
   }
   patricia_prefix_deref (prefix);
@@ -975,7 +975,7 @@ void
 lookup_then_remove (patricia_tree_t *tree, char *string)
 {
   patricia_node_t *node;
-  
+
   if ((node = try_search_exact (tree, string)))
     patricia_remove (tree, node);
 }
@@ -985,13 +985,13 @@ try_search_best (patricia_tree_t *tree, char *string)
 {
   prefix_t *prefix;
   patricia_node_t *node;
-  
+
   prefix = ascii2prefix (AF_INET, string);
   printf ("try_search_best: %s/%d", prefix_toa (prefix), prefix->bitlen);
   if ((node = patricia_search_best (tree, prefix)) == NULL)
     printf ("try_search_best: not found");
   else
-    printf ("try_search_best: %s/%d found", 
+    printf ("try_search_best: %s/%d found",
 	    prefix_toa (node->prefix), node->prefix->bitlen);
   patricia_prefix_deref (prefix);
   return (node);
