@@ -1,25 +1,24 @@
 /* -*- mode: c; c-basic-offset: 2 -*- */
-/* 
+/*
  * Copyright (C) 2009-2012 David Bird (Coova Technologies) <support@coova.com>
- * 
+ *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- * 
+ *
  */
 #include "system.h"
 #ifdef HAVE_SSL
 #include "chilli.h"
-#include "debug.h"
 
 static int openssl_init = 0;
 static openssl_env * sslenv_svr = 0;
@@ -36,13 +35,16 @@ openssl_env * initssl() {
     if (openssl_init == 0) {
       openssl_init = 1;
 #ifdef HAVE_OPENSSL
+#if OPENSSL_VERSION_NUMBER < 0x10100000L
+      if (_options.debug) {
+	SSL_load_error_strings();
+      }
       SSL_library_init();
-      if (_options.debug) SSL_load_error_strings();
-      SSLeay_add_all_algorithms();
-      SSLeay_add_ssl_algorithms();
+      OpenSSL_add_all_algorithms();
+#endif
 #else
       matrixSslOpen();
-      log_dbg("MatrixSslOpen()");
+      syslog(LOG_DEBUG, "%s(%d): MatrixSslOpen()", __FUNCTION__, __LINE__);
 #endif
     }
     openssl_env_init(sslenv_svr = calloc(1, sizeof(openssl_env)), 0, 1);
@@ -55,13 +57,16 @@ openssl_env * initssl_cli() {
     if (openssl_init == 0) {
       openssl_init = 1;
 #ifdef HAVE_OPENSSL
+#if OPENSSL_VERSION_NUMBER < 0x10100000L
+      if (_options.debug) {
+	SSL_load_error_strings();
+      }
       SSL_library_init();
-      if (_options.debug) SSL_load_error_strings();
-      SSLeay_add_all_algorithms();
-      SSLeay_add_ssl_algorithms();
+      OpenSSL_add_all_algorithms();
+#endif
 #else
       matrixSslOpen();
-      log_dbg("MatrixSslOpen()");
+      syslog(LOG_DEBUG, "%s(%d): MatrixSslOpen()", __FUNCTION__, __LINE__);
 #endif
     }
     openssl_env_init(sslenv_cli = calloc(1, sizeof(openssl_env)), 0, 0);
@@ -74,8 +79,8 @@ static int
 openssl_verify_peer_cb(int ok, X509_STORE_CTX *ctx) {
   int err = X509_STORE_CTX_get_error(ctx);
   if (err != X509_V_OK) {
-    log_err(errno, "peer certificate error: #%d : %s\n", 
-              err, X509_verify_cert_error_string(err));
+    syslog(LOG_ERR, "%d peer certificate error: #%d : %s\n",
+           errno, err, X509_verify_cert_error_string(err));
     return 0;
   }
   return 1;
@@ -91,9 +96,9 @@ openssl_verify_peer(openssl_env *env, int mode) {
 int
 openssl_use_certificate(openssl_env *env, char *file) {
   if (file)
-    if (SSL_CTX_use_certificate_file(env->ctx, file, SSL_FILETYPE_PEM) > 0)
+    if (SSL_CTX_use_certificate_chain_file(env->ctx, file) > 0)
       return 1;
-  log_err(errno, "could not load certificate file %s\n",file);
+  syslog(LOG_ERR, "%s: could not load certificate file %s\n", strerror(errno), file);
   return 0;
 }
 
@@ -105,17 +110,7 @@ openssl_use_privatekey(openssl_env *env, char *file) {
         (err2 = SSL_CTX_check_private_key(env->ctx)))
       return 1;
   }
-  log_err(errno, "could not load private key file %s (%d,%d)\n",file,err1,err2);
-  /*
-    {
-    BIO *bio_err = NULL;
-    bio_err = BIO_new_fp(stderr, BIO_NOCLOSE);
-    BIO_printf(bio_err,"unable to set private key file\n");
-    #if(_debug_)
-    ERR_print_errors(bio_err);
-    #endif
-    }
-  */
+  syslog(LOG_ERR, "%s: could not load private key file %s (%d,%d)\n", strerror(errno), file, err1, err2);
   return 0;
 }
 
@@ -123,95 +118,27 @@ int
 openssl_cacert_location(openssl_env *env, char *file, char *dir) {
   int err = SSL_CTX_load_verify_locations(env->ctx, file, dir);
   if (!err)
-    log_err(errno, "unable to load CA certificates.\n");
+    syslog(LOG_ERR, "%s: unable to load CA certificates.\n", strerror(errno));
   return err;
 }
 
-#if(0)
-static RSA *
-openssl_tmpRSA_cb(SSL *ssl, int export, int len) {
-  openssl_con *con = (openssl_con *)SSL_get_app_data(ssl);
-  openssl_env *env = con->env;
-  RSA *rsa = 0;
-
-  if (export) {
-    /* an export cipher is being used */
-    if (len == 512)
-      rsa = (RSA *)env->tmpKeys[OPENSSL_TMPKEY_RSA512];
-    else if (len == 1024)
-      rsa = (RSA *)env->tmpKeys[OPENSSL_TMPKEY_RSA1024];
-    else
-      /* too expensive to generate on-the-fly, use 1024bit */
-      rsa = (RSA *)env->tmpKeys[OPENSSL_TMPKEY_RSA1024];
-  }
-  else {
-    /* sign-only certificate situation exists */
-    rsa = (RSA *)env->tmpKeys[OPENSSL_TMPKEY_RSA1024];
-  }
-  return rsa;
-}
-
-static DH *
-openssl_tmpDH_cb(SSL *ssl, int export, int len) {
-  openssl_con *con = (openssl_con *)SSL_get_app_data(ssl);
-  openssl_env *env = con->env;
-  DH *dh = 0;
-
-  if (export) {
-    /* an export cipher is being used */
-    if (len == 512)
-      dh = (DH *)env->tmpKeys[OPENSSL_TMPKEY_DH512];
-    else if (len == 1024)
-      dh = (DH *)env->tmpKeys[OPENSSL_TMPKEY_DH1024];
-    else
-      /* too expensive to generate on-the-fly, use 1024bit */
-      dh = (DH *)env->tmpKeys[OPENSSL_TMPKEY_DH1024];
-  }
-  else {
-    /* sign-only certificate situation exists */
-    dh = (DH *)env->tmpKeys[OPENSSL_TMPKEY_DH1024];
-  }
-  return dh;
-}
-
-static void
-openssl_tmp_genkeys(openssl_env *env) {
-
-  if ((env->tmpKeys[OPENSSL_TMPKEY_RSA512] = RSA_generate_key(512, RSA_F4, NULL, NULL)) == NULL) {
-    log_err(errno, "could not generate tmp 512bit RSA key\n");
-  }
-
-  if ((env->tmpKeys[OPENSSL_TMPKEY_RSA1024] = RSA_generate_key(1024, RSA_F4, NULL, NULL)) == NULL) {
-    log_err(errno, "could not generate tmp 1024bit RSA key\n");
-  }
-
-  if ((env->tmpKeys[OPENSSL_TMPKEY_DH512] = openssl_dh_tmpkey(512)) == NULL) {
-    log_err(errno, "could not generate tmp 512bit DH key\n");
-  }
-
-  if ((env->tmpKeys[OPENSSL_TMPKEY_DH1024] = openssl_dh_tmpkey(1024)) == NULL) {
-    log_err(errno, "could not generate tmp 512bit DH key\n");
-  }
-}
-#endif
-
 int
 _openssl_env_init(openssl_env *env, char *engine, int server) {
   /*
    * Create an OpenSSL environment (method and context).
-   * If ``server'' is 1, the environment is that of a SSL 
+   * If ``server'' is 1, the environment is that of a SSL
    * server.
    */
-  if (server) {
-    env->meth = SSLv23_server_method();
-  } else {
-    env->meth = TLSv1_client_method();
-  }
+  const long options = SSL_OP_NO_SSLv2 | SSL_OP_NO_SSLv3 | SSL_OP_NO_COMPRESSION;
+  env->meth = SSLv23_method();
   env->ctx = SSL_CTX_new(env->meth);
-  SSL_CTX_set_options(env->ctx, SSL_OP_ALL);
-#ifdef HAVE_OPENSSL_ENGINE
+  SSL_CTX_set_options(env->ctx, options);
+  if (_options.sslciphers) {
+    SSL_CTX_set_cipher_list(env->ctx, _options.sslciphers);
+  }
+#ifndef OPENSSL_NO_ENGINE
   if (engine) {
-  retry:
+ retry:
     if ((env->engine = ENGINE_by_id(engine)) == NULL) {
       fprintf(stderr,"invalid engine \"%s\"\n", engine);
       ENGINE_free(env->engine);
@@ -242,9 +169,9 @@ _openssl_env_init(openssl_env *env, char *engine, int server) {
 
 #ifdef HAVE_OPENSSL
 static int _openssl_passwd(char *buf, int size, int rwflag, void *ud) {
-  safe_strncpy(buf, _options.sslkeypass, size);
+  strlcpy(buf, _options.sslkeypass, size);
   memset(_options.sslkeypass,'x',strlen(_options.sslkeypass));
-  return 0;
+  return strlen(buf);
 }
 #endif
 
@@ -252,7 +179,7 @@ int
 openssl_env_init(openssl_env *env, char *engine, int server) {
 
   if (!_options.sslcertfile || !_options.sslkeyfile) {
-    log_err(0, "options sslcertfile and sslkeyfile are required");
+    syslog(LOG_ERR, "options sslcertfile and sslkeyfile are required");
     return 0;
   }
 
@@ -263,35 +190,35 @@ openssl_env_init(openssl_env *env, char *engine, int server) {
     if (_options.sslkeypass) {
       SSL_CTX_set_default_passwd_cb(env->ctx, _openssl_passwd);
     }
-    
+
     if (!openssl_use_certificate(env, _options.sslcertfile) ||
 	!openssl_use_privatekey(env, _options.sslkeyfile)) {
-      log_err(0, "failed reading setup sslcertfile and/or sslkeyfile");
+      syslog(LOG_ERR, "failed reading setup sslcertfile and/or sslkeyfile");
       return 0;
     }
 
     if (_options.sslcafile) {
       if (!openssl_cacert_location(env, _options.sslcafile, 0)) {
-	log_err(0, "failed reading sslcafile");
+	syslog(LOG_ERR, "failed reading sslcafile");
 	return 0;
       }
     }
-    
+
     env->ready = 1;
     return err;
   }
 #else
-  log_dbg("MatrixSSL Setup:");
-  log_dbg("SSL cert: %s",_options.sslcertfile);
-  log_dbg("SSL key: %s",_options.sslkeyfile);
-  log_dbg("SSL pass: %s",_options.sslkeypass?_options.sslkeypass:"null");
-  log_dbg("SSL ca: %s",_options.sslcafile?_options.sslcafile:"null");
+  syslog(LOG_DEBUG, "%s(%d): MatrixSSL Setup:", __FUNCTION__, __LINE__);
+  syslog(LOG_DEBUG, "%s(%d): SSL cert: %s", __FUNCTION__, __LINE__, _options.sslcertfile);
+  syslog(LOG_DEBUG, "%s(%d): SSL key: %s", __FUNCTION__, __LINE__, _options.sslkeyfile);
+  syslog(LOG_DEBUG, "%s(%d): SSL pass: %s", __FUNCTION__, __LINE__, _options.sslkeypass?_options.sslkeypass:"null");
+  syslog(LOG_DEBUG, "%s(%d): SSL ca: %s", __FUNCTION__, __LINE__, _options.sslcafile?_options.sslcafile:"null");
   if ( matrixSslReadKeys( &env->keys,
-			  _options.sslcertfile, 
-			  _options.sslkeyfile, 
-			  _options.sslkeypass, 
+			  _options.sslcertfile,
+			  _options.sslkeyfile,
+			  _options.sslkeypass,
 			  _options.sslcafile ) < 0 ) {
-    log_err(errno, "could not load ssl certificate or and/or key file");
+    syslog(LOG_ERR, "%s: could not load ssl certificate or and/or key file", strerror(errno));
     return 0;
   }
 
@@ -302,7 +229,7 @@ openssl_env_init(openssl_env *env, char *engine, int server) {
 
 #ifdef HAVE_MATRIXSSL
 static int certValidator(sslCertInfo_t *t, void *arg) {
-  log_dbg("MatrixSSL: certValidator()");
+  syslog(LOG_DEBUG, "%s(%d): MatrixSSL: certValidator()", __FUNCTION__, __LINE__);
   return 1;
 }
 #endif
@@ -314,16 +241,16 @@ openssl_connect_fd(openssl_env *env, int fd, int timeout) {
 
   c->env = env;
 #ifdef HAVE_OPENSSL
-  c->con = (SSL *)SSL_new(env->ctx); 
+  c->con = (SSL *)SSL_new(env->ctx);
 #elif  HAVE_MATRIXSSL
-  c->con = (SSL *)SSL_new(env->keys, 0); 
+  c->con = (SSL *)SSL_new(env->keys, 0);
 #endif
   c->sock = fd;
   c->timeout = timeout;
 
   SSL_set_fd(c->con, c->sock);
 
-#ifdef HAVE_OPENSSL  
+#ifdef HAVE_OPENSSL
 #ifdef HAVE_OPENSSL_ENGINE
   SSL_set_app_data(c->con, c);
 #endif
@@ -334,7 +261,7 @@ openssl_connect_fd(openssl_env *env, int fd, int timeout) {
 #if(_debug_)
     unsigned long error;
     while ((error = ERR_get_error())) {
-      log_dbg("TLS: %s", ERR_error_string(error, NULL));
+      syslog(LOG_DEBUG, "%s(%d): TLS: %s", __FUNCTION__, __LINE__, ERR_error_string(error, NULL));
       is_error = 1;
     }
 #endif
@@ -345,7 +272,7 @@ openssl_connect_fd(openssl_env *env, int fd, int timeout) {
   }
 #elif  HAVE_MATRIXSSL
   if (!SSL_connect(c->con, certValidator, c)) {
-    log_err(errno, "openssl_connect_fd");
+    syslog(LOG_ERR, "%s: openssl_connect_fd", strerror(errno));
     openssl_free(c);
     return 0;
   }
@@ -357,7 +284,7 @@ openssl_connect_fd(openssl_env *env, int fd, int timeout) {
 int
 openssl_check_accept(openssl_con *c, struct redir_conn_t *conn) {
 
-#ifdef HAVE_OPENSSL  
+#ifdef HAVE_OPENSSL
   int rc;
 
   if (!c || !c->con) return -1;
@@ -367,45 +294,45 @@ openssl_check_accept(openssl_con *c, struct redir_conn_t *conn) {
     if ((rc = SSL_accept(c->con)) <= 0) {
 
       int err = SSL_get_error(c->con, rc);
-      
+
       switch (err) {
-      case SSL_ERROR_WANT_READ:
-      case SSL_ERROR_WANT_WRITE: 
-	return 1;
-	
-      case SSL_ERROR_SYSCALL:
-	if (errno != EINTR) {
+        case SSL_ERROR_WANT_READ:
+        case SSL_ERROR_WANT_WRITE:
+          return 1;
+
+        case SSL_ERROR_SYSCALL:
+          if (errno != EINTR) {
 #if(_debug_ > 1)
-	  if (errno > 0) {
-	    log_dbg("SSL handshake interrupted by system [Hint: Stop button pressed in browser?!]");
-         }
-	  else {
-	    log_dbg("Spurious SSL handshake interrupt [Hint: Usually just one of those OpenSSL confusions!?]");
-        }
+            if (errno > 0) {
+              syslog(LOG_DEBUG, "%s(%d): SSL handshake interrupted by system [Hint: Stop button pressed in browser?!]", __FUNCTION__, __LINE__);
+            }
+            else {
+              syslog(LOG_DEBUG, "%s(%d): Spurious SSL handshake interrupt [Hint: Usually just one of those OpenSSL confusions!?]", __FUNCTION__, __LINE__);
+            }
 #endif
-	}
-	break;
+          }
+          break;
       }
-      
+
       return -1;
-      
+
     } else {
-      
+
 #ifdef HAVE_OPENSSL_ENGINE
       X509 *peer_cert = SSL_get_peer_certificate(c->con);
-      
+
       if (peer_cert) {
 	char subj[1024];
-	
+
 	X509_NAME_oneline(X509_get_subject_name(peer_cert),subj,sizeof(subj));
-	
+
 	if (SSL_get_verify_result(c->con) != X509_V_OK) {
-	  log_dbg("auth_failed: %s", subj);
+	  syslog(LOG_DEBUG, "%s(%d): auth_failed: %s", __FUNCTION__, __LINE__, subj);
 	  X509_free(peer_cert);
 	  return -1;
 	}
-		
-	log_dbg("auth_success: %s", subj);
+
+	syslog(LOG_DEBUG, "%s(%d): auth_success: %s", __FUNCTION__, __LINE__, subj);
 	if (conn) conn->s_params.flags |= ADMIN_LOGIN;
 
 	if (_options.debug) {
@@ -413,23 +340,23 @@ openssl_check_accept(openssl_con *c, struct redir_conn_t *conn) {
 #if OPENSSL_VERSION_NUMBER >= 0x10000000L
  	  const
 #endif
-	  SSL_CIPHER *cipher;
+              SSL_CIPHER *cipher;
 	  char b[512];
-	  log_dbg("Debugging: SSL Information:\n");
+	  syslog(LOG_DEBUG, "%s(%d): Debugging: SSL Information:\n", __FUNCTION__, __LINE__);
 	  cipher = SSL_get_current_cipher(c->con);
-	  log_dbg("  Protocol: %s, %s with %.*s bit key\n", 
-		  SSL_CIPHER_get_version(cipher),
-		  (char*)SSL_CIPHER_get_name(cipher),
-		  sprintf(b, "%d", EVP_PKEY_bits(pktmp)), b);
-	  log_dbg("  Subject:  %s\n", subj);
+	  syslog(LOG_DEBUG, "%s(%d): Protocol: %s, %s with %.*s bit key\n", __FUNCTION__, __LINE__,
+                 SSL_CIPHER_get_version(cipher),
+                 (char*)SSL_CIPHER_get_name(cipher),
+                 sprintf(b, "%d", EVP_PKEY_bits(pktmp)), b);
+	  syslog(LOG_DEBUG, "%s(%d): Subject:  %s\n", __FUNCTION__, __LINE__, subj);
 	  X509_NAME_oneline(X509_get_issuer_name(peer_cert),b,sizeof(b));
-	  log_dbg("  Issuer:   %s\n", b);
+	  syslog(LOG_DEBUG, "%s(%d): Issuer:   %s\n", __FUNCTION__, __LINE__, b);
 	  EVP_PKEY_free(pktmp);
 	}
-	
+
 	X509_free(peer_cert);
       } else {
-	log_dbg("no SSL certificate");
+	syslog(LOG_DEBUG, "%s(%d): no SSL certificate", __FUNCTION__, __LINE__);
       }
 #endif
     }
@@ -461,22 +388,23 @@ openssl_accept_fd(openssl_env *env, int fd, int timeout, struct redir_conn_t *co
   if (!c) return 0;
 
   if (!env || !env->ready) {
-    log_err(0, "SSL not available!");
+    syslog(LOG_ERR, "SSL not available!");
+    openssl_free(c);
     return 0;
   }
 
   c->env = env;
 #ifdef HAVE_OPENSSL
-  c->con = (SSL *)SSL_new(env->ctx); 
+  c->con = (SSL *)SSL_new(env->ctx);
 #elif  HAVE_MATRIXSSL
-  c->con = (SSL *)SSL_new(env->keys, SSL_FLAGS_SERVER); 
+  c->con = (SSL *)SSL_new(env->keys, SSL_FLAGS_SERVER);
 #endif
   c->sock = fd;
   c->timeout = timeout;
 
   SSL_set_fd(c->con, c->sock);
 
-#ifdef HAVE_OPENSSL  
+#ifdef HAVE_OPENSSL
 #ifdef HAVE_OPENSSL_ENGINE
   SSL_clear(c->con);
 #endif
@@ -497,13 +425,13 @@ openssl_accept_fd(openssl_env *env, int fd, int timeout, struct redir_conn_t *co
   }
 
 #elif  HAVE_MATRIXSSL
-  
+
   /* ndelay_off(c->sock); */
 
   matrixSslSetCertValidator(c->con->ssl, certValidator, c->con->keys);
 
   if ((rc = SSL_accept2(c->con)) < 0) {
-    log_err(c->con->status, "SSL accept failure");
+    syslog(LOG_ERR, "%s: SSL accept failure %s", strerror(errno), c->con->status);
     openssl_free(c);
     return 0;
   }
@@ -521,42 +449,42 @@ openssl_accept_fd(openssl_env *env, int fd, int timeout, struct redir_conn_t *co
 
 int
 openssl_error(openssl_con *con, int ret, char *func) {
-#ifdef HAVE_OPENSSL  
+#ifdef HAVE_OPENSSL
   int err = -1;
   if (con->con) {
     err = SSL_get_error(con->con, ret);
 #if(_debug_ > 1)
-    log_dbg("SSL: (%s()) %s", func,
-	    err == SSL_ERROR_NONE ? "None": 
-            err == SSL_ERROR_ZERO_RETURN ? "Return!":
-	    err == SSL_ERROR_WANT_READ ? "Read (continue)":
-	    err == SSL_ERROR_WANT_WRITE ? "Write (continue)":
-	    err == SSL_ERROR_WANT_X509_LOOKUP ? "Lookup (continue)":
-	    err == SSL_ERROR_SYSCALL ? "Syscall error, abort!":
-	    err == SSL_ERROR_SSL ? "SSL error, abort!":
-	    "Error");
+    syslog(LOG_DEBUG, "%s(%d): SSL: (%s()) %s", __FUNCTION__, __LINE__, func,
+           err == SSL_ERROR_NONE ? "None":
+           err == SSL_ERROR_ZERO_RETURN ? "Return!":
+           err == SSL_ERROR_WANT_READ ? "Read (continue)":
+           err == SSL_ERROR_WANT_WRITE ? "Write (continue)":
+           err == SSL_ERROR_WANT_X509_LOOKUP ? "Lookup (continue)":
+           err == SSL_ERROR_SYSCALL ? "Syscall error, abort!":
+           err == SSL_ERROR_SSL ? "SSL error, abort!":
+           "Error");
 #endif
     switch (err) {
-    case SSL_ERROR_NONE: return 0;
-    case SSL_ERROR_WANT_READ: return 1;
-    case SSL_ERROR_WANT_WRITE: return 2;
-    case SSL_ERROR_SYSCALL: 
-      /*
-       * This is a protocol violation, but we got
-       * an EOF (remote connection did a shutdown(fd, 1).
-       * We will treat it as a zero value.
-       */
-      if (ret == 0) return 0;
-      /* If some other error, fall through */
-    case SSL_ERROR_ZERO_RETURN: openssl_shutdown(con, 0);
-    case SSL_ERROR_SSL: return -1;
-    default: break;
+      case SSL_ERROR_NONE: return 0;
+      case SSL_ERROR_WANT_READ: return 1;
+      case SSL_ERROR_WANT_WRITE: return 2;
+      case SSL_ERROR_SYSCALL:
+        /*
+         * This is a protocol violation, but we got
+         * an EOF (remote connection did a shutdown(fd, 1).
+         * We will treat it as a zero value.
+         */
+        if (ret == 0) return 0;
+        /* If some other error, fall through */
+      case SSL_ERROR_ZERO_RETURN: openssl_shutdown(con, 0);
+      case SSL_ERROR_SSL: return -1;
+      default: break;
     }
     return 1;
   }
   return err;
 #else
-  log_err(errno, "ssl error in %s", func);
+  syslog(LOG_ERR, "%s: ssl error in %s", strerror(errno), func);
   return 0;
 #endif
 }
@@ -570,17 +498,17 @@ openssl_shutdown(openssl_con *con, int state) {
    */
   if (con) {
     switch(state) {
-    case 0: SSL_set_shutdown(con->con, SSL_RECEIVED_SHUTDOWN); break;
-    case 1: SSL_set_shutdown(con->con, SSL_SENT_SHUTDOWN); break;
-    case 2: SSL_set_shutdown(con->con, SSL_RECEIVED_SHUTDOWN|SSL_SENT_SHUTDOWN); break;
+      case 0: SSL_set_shutdown(con->con, SSL_RECEIVED_SHUTDOWN); break;
+      case 1: SSL_set_shutdown(con->con, SSL_SENT_SHUTDOWN); break;
+      case 2: SSL_set_shutdown(con->con, SSL_RECEIVED_SHUTDOWN|SSL_SENT_SHUTDOWN); break;
     }
-    for (i = 0; i < 4; i++) 
-      if (SSL_shutdown(con->con)) 
+    for (i = 0; i < 4; i++)
+      if (SSL_shutdown(con->con))
 	break;
   }
 #endif
 }
-  
+
 int
 openssl_read(openssl_con *con, char *b, int l, int t) {
   int rbytes = 0;
@@ -604,12 +532,12 @@ openssl_read(openssl_con *con, char *b, int l, int t) {
     if (select(fd + 1,&rfds,&wfds,(fd_set *) 0,&tv) == -1) return -1;
     if (!FD_ISSET(fd, &rfds) && !FD_ISSET(fd, &wfds)) return 0;
   }
-    
- repeat_read:
+
+repeat_read:
 
   rbytes = SSL_read(con->con, b, l);
 
-  log_dbg("--- SSL_read() = %d", rbytes);
+  syslog(LOG_DEBUG, "%s(%d): --- SSL_read() = %d", __FUNCTION__, __LINE__, rbytes);
 
   if (rbytes <= 0) {
     err = openssl_error(con, rbytes, "openssl_read");
@@ -630,34 +558,34 @@ openssl_write(openssl_con *con, char *b, int l, int t) {
     fd_set wfds;
     struct timeval tv;
     int fd = con->sock;
-    
+
     tv.tv_sec = t;
     tv.tv_usec = 0;
-    
+
     FD_ZERO(&wfds);
     FD_SET(fd, &wfds);
-    
+
     if (select(fd + 1,(fd_set *) 0,&wfds,(fd_set *) 0,&tv) == -1) return -1;
     if (!FD_ISSET(fd, &wfds)) return 0;
   }
 
   while (sent < l) {
 
-  repeat_write:
-    
+ repeat_write:
+
     wrt = SSL_write(con->con, b+sent, l-sent);
-    
+
     if (wrt <= 0) {
       err = openssl_error(con, wrt, "openssl_write");
       if (err == -1) return err;
       else if (err > 0) {
 #if(_debug_)
-	//log_dbg("ssl_repeat_write");
+	//syslog(LOG_DEBUG, "ssl_repeat_write");
 #endif
 	goto repeat_write;
       }
       break;
-    } 
+    }
 
     sent += wrt;
   }
@@ -670,10 +598,10 @@ openssl_free(openssl_con *con) {
   SSL *c = con->con;
   if (c) {
 #ifdef HAVE_OPENSSL
-    SSL_set_connect_state(c); 
+    SSL_set_connect_state(c);
 #endif
-    SSL_free(c); 
-    con->con = 0; 
+    SSL_free(c);
+    con->con = 0;
   }
   free(con);
 }
@@ -681,18 +609,18 @@ openssl_free(openssl_con *con) {
 void
 openssl_env_free(openssl_env *env) {
 #if(_debug_)
-  log_dbg("Freeing SSL environemnt");
+  syslog(LOG_DEBUG, "%s(%d): Freeing SSL environemnt", __FUNCTION__, __LINE__);
 #endif
 #ifdef HAVE_OPENSSL
   if (env->ctx) SSL_CTX_free(env->ctx);
-#ifdef HAVE_OPENSSL_ENGINE
+#ifndef OPENSSL_NO_ENGINE
   if (env->engine) ENGINE_free(env->engine);
 #endif
 #endif
   free(env);
 }
 
-int 
+int
 openssl_pending(openssl_con *con) {
   if (con->con) {
     int pending = SSL_pending(con->con);
